==> jc-1.4.0.tar.gz: javax/rmi/ORB.h <==
// public class javax.rmi.ORB

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c2b8fe5fa3dd39d9 javax_rmi_ORB

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_rmi_ORB_H_
#define _JC_javax_rmi_ORB_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_rmi_ORB$sub_refs	_jc_javax_rmi_ORB$sub_refs;
typedef struct _jc_javax_rmi_ORB$sub_nonrefs	_jc_javax_rmi_ORB$sub_nonrefs;
typedef struct _jc_javax_rmi_ORB$refs	_jc_javax_rmi_ORB$refs;
typedef struct _jc_javax_rmi_ORB$nonrefs	_jc_javax_rmi_ORB$nonrefs;
typedef struct _jc_javax_rmi_ORB$object	_jc_javax_rmi_ORB$object;

typedef const struct _jc_javax_rmi_ORB$vmethods	_jc_javax_rmi_ORB$vmethods;
typedef const struct _jc_javax_rmi_ORB$vtable	_jc_javax_rmi_ORB$vtable;
typedef const struct _jc_javax_rmi_ORB$vtype	_jc_javax_rmi_ORB$vtype;

// Constructors
extern void _jc_javax_rmi_ORB$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_ORB$object *);

// Virtual methods structure
struct _jc_javax_rmi_ORB$vmethods {
};

// Vtable
struct _jc_javax_rmi_ORB$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_ORB$vmethods	javax_rmi_ORB;
};

// Vtype
struct _jc_javax_rmi_ORB$vtype {
	_jc_type			type;
	_jc_javax_rmi_ORB$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_ORB$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_ORB$refs {
    _jc_javax_rmi_ORB$sub_refs	javax_rmi_ORB;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_ORB$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_ORB$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_ORB$sub_nonrefs	javax_rmi_ORB;
};

// Object instance structure
struct _jc_javax_rmi_ORB$object {
	_jc_javax_rmi_ORB$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_ORB$vtype	*vtype;
	_jc_javax_rmi_ORB$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_ORB$vtype _jc_javax_rmi_ORB$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_ORB, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_ORB$class_object;

#endif	/* _JC_javax_rmi_ORB_H_ */

==> jc-1.4.6.tar.gz: javax/rmi/ORB.h <==
// public class javax.rmi.ORB

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c2b8fe5fa3dd39d9 javax_rmi_ORB

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_rmi_ORB_H_
#define _JC_javax_rmi_ORB_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_rmi_ORB$sub_refs	_jc_javax_rmi_ORB$sub_refs;
typedef struct _jc_javax_rmi_ORB$sub_nonrefs	_jc_javax_rmi_ORB$sub_nonrefs;
typedef struct _jc_javax_rmi_ORB$refs	_jc_javax_rmi_ORB$refs;
typedef struct _jc_javax_rmi_ORB$nonrefs	_jc_javax_rmi_ORB$nonrefs;
typedef struct _jc_javax_rmi_ORB$object	_jc_javax_rmi_ORB$object;

typedef const struct _jc_javax_rmi_ORB$vmethods	_jc_javax_rmi_ORB$vmethods;
typedef const struct _jc_javax_rmi_ORB$vtable	_jc_javax_rmi_ORB$vtable;
typedef const struct _jc_javax_rmi_ORB$vtype	_jc_javax_rmi_ORB$vtype;

// Constructors
extern void _jc_javax_rmi_ORB$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_ORB$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_rmi_ORB$vmethods {
};

// Vtable
struct _jc_javax_rmi_ORB$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_ORB$vmethods	javax_rmi_ORB;
};

// Vtype
struct _jc_javax_rmi_ORB$vtype {
	_jc_type			type;
	_jc_javax_rmi_ORB$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_ORB$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_ORB$refs {
    _jc_javax_rmi_ORB$sub_refs	javax_rmi_ORB;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_ORB$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_ORB$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_ORB$sub_nonrefs	javax_rmi_ORB;
};

// Object instance structure
struct _jc_javax_rmi_ORB$object {
	_jc_javax_rmi_ORB$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_ORB$vtype	*vtype;
	_jc_javax_rmi_ORB$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_ORB$vtype _jc_javax_rmi_ORB$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_ORB, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_ORB$class_object;

#endif	/* _JC_javax_rmi_ORB_H_ */
